@@ -207,7 +207,6 @@ void compute_dihedral_angle( float A[3], float B[3], float C[3], float D[3], flo
 */
 void coordinate_transformer( float X[4][500],float EX[4][500], int N, int NAT1, int NAT2, int NAT3){ 
   int i,j,k ; 
-  float AX[4][500] ; 
   float T[4][4] ; 
   float Tee[4][4] ; 
   float Tphi[4][4] ; 
@@ -217,7 +216,7 @@ void coordinate_transformer( float X[4][500],float EX[4][500], int N, int NAT1,
   {
     sq[k] = X[k][NAT1] ; 
     for( j = 1 ; j <= N ; j++ ) 
-     { AX[k][j] = X[k][j] ; 
+     {  
         X[k][j] -= sq[k] ; 
      }
   }
