@@ -214,8 +214,8 @@ void CALCULATE_EDGE_WEIGHTS( int a , int b , float ***edge_weights )
 		Coords_Set_moving[i] = new float [3] ;
 	}
 	float RMSD;
-	float ROTATION_MAT[3][3] , prev_ROTMAT[3][3];
-	double CM_stationary[3] ,  CM_moving[3] ; double prev_CM_S[3] ,  prev_CM_M[3] ;
+	float ROTATION_MAT[3][3];
+	double CM_stationary[3] ,  CM_moving[3] ;
 
 	for( int I = 0 ; I < PROT_SIZES[a] - MIN_CP_WINDOW_SIZE + 1; I++ )
 		for( int J = 0 ; J < PROT_SIZES[b] - MIN_CP_WINDOW_SIZE + 1 ; J++ )
@@ -270,14 +270,6 @@ void CALCULATE_EDGE_WEIGHTS( int a , int b , float ***edge_weights )
 				
 				prev_rmsd = RMSD ;
 				if( tmp_ind < 4 ) prev_rmsds[tmp_ind++] = RMSD ;
-				//copy ROTATION_MAT to prev_ROTMAT, CM_stationary -> prev_CM_S , and CM_moving -> prev_CM_M
-				for( int i = 0 ; i < 3 ; i++ )
-				{
-					for( int j = 0 ; j <  3; j++ )
-						prev_ROTMAT[i][j] = ROTATION_MAT[i][j] ;
-					prev_CM_S[i] = CM_stationary[i] ; 
-					prev_CM_M[i] = CM_moving[i] ; 
-				}
 			}
 			//cout << I << " " << J << " " << RMSD << " " <<  prev_rmsd << endl ; 
 			// find similarity score of this maximal fragment
