@@ -216,9 +216,6 @@ void EXTENDED_LIBRARY_GENERATION()
 							  //*/
 							  else if( B!= -99 && B_orig == -99 && merge_trav->mates[1][B] == -99 )
 							  {
-							      float AAA ;
-							      AAA = Edge_Weights[ind][A][B] ;
-
 							      /*
 								 The paln here is not to extended an arc between A and B thro' C if
 								 A and B are both unmatched in the pairwise alignment. However if 
