@@ -50,7 +50,6 @@ int CHECK_NCHAINS_IN_PDB( char *fname )
 {
 	int NCHAINS = 0 ;
 	int chain_flag = OFF ;
-	int chain_id = -1;
 	char buffer[90];
 	ifstream pdb( fname , ios::in ) ;
 	if( !pdb )
@@ -69,7 +68,6 @@ int CHECK_NCHAINS_IN_PDB( char *fname )
 		if( buffer[0] == 'A' && buffer[1] == 'T' && buffer[2] == 'O' && buffer[3] == 'M' && chain_flag == OFF )
 		{
 			chain_flag = ON ;
-			chain_id = buffer[ 21 ] ;
 		}
 			
 		if( chain_flag == ON && buffer[0] == 'T' && buffer[1] == 'E' && 
