@@ -658,8 +658,8 @@ void REFINE_PAIRWISE_ALIGNMENT( int a , int b , float **edge_weights )
 			int Y = A2I_hash[1][pos1] ;
 			if(X!= -99 && Y!= -99)	edge_weights[ X ][ Y ] = -1 ;
 
-			Global_Library[g_index].mates[0][X] = -99 ;
-			Global_Library[g_index].mates[1][Y] = -99 ;
+			if (X != -99) Global_Library[g_index].mates[0][X] = -99 ;
+			if (Y != -99) Global_Library[g_index].mates[1][Y] = -99 ;
 		}
 		pos1-- ;
 	}
